# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-11-19 08:23
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='RichTextImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('app_name', models.CharField(max_length=180, null=True, verbose_name='app\u540d')),
                ('model_name', models.CharField(max_length=180, null=True, verbose_name='model\u540d')),
                ('image', models.ImageField(upload_to='bee_django_richtext/image', verbose_name='\u56fe\u7247')),
                ('upload_at', models.DateTimeField(auto_now_add=True, verbose_name='\u65f6\u95f4')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'db_table': 'bee_django_richtext_image',
            },
        ),
    ]
